==> transmission_2.13.orig.tar.bz2: transmission-2.13/gtk/dialogs.h <==
/******************************************************************************
 * $Id: dialogs.h 10993 2010-07-11 06:46:46Z charles $
 *
 * Copyright (c) 2005-2008 Transmission authors and contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *****************************************************************************/

#ifndef TG_PREFS_H
#define TG_PREFS_H

#include "tr-core.h"
#include "tr-torrent.h"
#include "util.h"


/* used for a callback function with a data parameter */
typedef void ( *callbackfunc_t )( gpointer );

/* prompt if the user wants to quit, calls func with cbdata if they do */
GtkWidget *  askquit( TrCore          * core,
                      GtkWindow       * parent,
                      callbackfunc_t    func,
                      gpointer          cbdata );

void confirmRemove( GtkWindow * parent,
                    TrCore    * core,
                    GSList    * gtorrents,
                    gboolean    doDelete );

#endif /* TG_PREFS_H */

==> transmission-2.22.tar.bz2: transmission-2.22/gtk/dialogs.h <==
/******************************************************************************
 * $Id: dialogs.h 11709 2011-01-19 13:48:47Z jordan $
 *
 * Copyright (c) Transmission authors and contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *****************************************************************************/

#ifndef GTR_DIALOGS_H
#define GTR_DIALOGS_H

#include "tr-core.h"
#include "tr-torrent.h"
#include "util.h"


/* used for a callback function with a data parameter */
typedef void ( *callbackfunc_t )( gpointer );

/**
 * Prompt the user to confirm exiting the app.
 * Call func(cbdata) if user confirms.
 */
GtkWidget * gtr_confirm_quit   ( GtkWindow       * parent,
                                 TrCore          * core,
                                 callbackfunc_t    func,
                                 gpointer          cbdata );

/**
 * Prompt the user to confirm removing a torrent.
 */
void        gtr_confirm_remove ( GtkWindow * parent,
                                 TrCore    * core,
                                 GSList    * gtorrents,
                                 gboolean    doDelete );

#endif /* GTR_DIALOGS_H */
